require 'modshogun'

features_p = Modshogun::GaussianBlobsDataGenerator.new 
features_q = Modshogun::GaussianBlobsDataGenerator.new 

#![create_instance]
mmd = Modshogun::LinearTimeMMD.new 
kernel = Modshogun::GaussianKernel.new 10, 1
mmd.set_kernel kernel
mmd.set_p features_p
mmd.set_q features_q
mmd.set_num_samples_p 1000
mmd.set_num_samples_q 1000
alpha = 0.05
#![create_instance]

#![set_burst]
mmd.set_num_blocks_per_burst 1000
#![set_burst]

#![estimate_mmd]
statistic = mmd.compute_statistic 
#![estimate_mmd]

#![perform_test]
threshold = mmd.compute_threshold alpha
p_value = mmd.compute_p_value statistic
#![perform_test]

#![add_kernels]
kernel1 = Modshogun::GaussianKernel.new 10, 0.1
kernel2 = Modshogun::GaussianKernel.new 10, 1
kernel3 = Modshogun::GaussianKernel.new 10, 10
mmd.add_kernel kernel1
mmd.add_kernel kernel2
mmd.add_kernel kernel3
#![add_kernels]

#![enable_train_test_mode]
mmd.set_train_test_mode true
mmd.set_train_test_ratio 1
#![enable_train_test_mode]

#![select_kernel_single]
mmd.set_kernel_selection_strategy Modshogun::KSM_MAXIMIZE_POWER
mmd.select_kernel 
learnt_kernel_single = Modshogun::GaussianKernel.obtain_from_generic mmd.get_kernel 
width = learnt_kernel_single.get_width 
#![select_kernel_single]

#![select_kernel_combined]
mmd.set_kernel_selection_strategy Modshogun::KSM_MAXIMIZE_POWER, true
mmd.select_kernel 
learnt_kernel_combined = Modshogun::CombinedKernel.obtain_from_generic mmd.get_kernel 
weights = learnt_kernel_combined.get_subkernel_weights 
#![select_kernel_combined]

#![perform_test_optimized]
statistic_optimized = mmd.compute_statistic 
p_value_optimized = mmd.compute_p_value statistic
#![perform_test_optimized]

# Serialize output for integration testing (automatically generated)
__sg_storage = Modshogun::WrappedObjectArray.new 
__sg_storage_file = Modshogun::SerializableAsciiFile.new "linear_time_mmd.dat", 'w'
__sg_storage.append_wrapped_real alpha, "alpha"
__sg_storage.append_wrapped_real statistic, "statistic"
__sg_storage.append_wrapped_real threshold, "threshold"
__sg_storage.append_wrapped_real p_value, "p_value"
__sg_storage.append_wrapped_real width, "width"
__sg_storage.append_wrapped_real_vector weights, "weights"
__sg_storage.append_wrapped_real statistic_optimized, "statistic_optimized"
__sg_storage.append_wrapped_real p_value_optimized, "p_value_optimized"
__sg_storage.save_serializable __sg_storage_file
